package com.bweb.controller.student;

import com.hfkj.common.exception.ErrorCode;
import com.hfkj.common.exception.ErrorHelp;
import com.hfkj.common.exception.SysCode;
import com.hfkj.common.security.SessionObject;
import com.hfkj.common.security.UserCenter;
import com.hfkj.common.utils.ResponseMsgUtil;
import com.hfkj.entity.StudentItem;
import com.hfkj.model.ResponseData;
import com.hfkj.service.student.StudentItemService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.Date;

@RestController
@RequestMapping(value="/studentItem")
@Api(value="学生项目")
public class StudentItemController {
    Logger log = LoggerFactory.getLogger(StudentItemController.class);
    @Resource
    private UserCenter userCenter;
    @Resource
    private StudentItemService studentItemService;

    @RequestMapping(value="/create",method = RequestMethod.POST)
    @ResponseBody
    @ApiOperation(value = "创建学生项目")
    public ResponseData create(@RequestBody StudentItem body) {
        try {
            if (body == null
                    || StringUtils.isBlank(body.getName())
                    || body.getItemType() == null
                    || body.getGradeType() == null
                    || body.getSportsType() == null

            ) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.REQ_PARAMS_ERROR, "");
            }
            SessionObject sessionModel = userCenter.getSessionModel(SessionObject.class);
            if (sessionModel == null) {
                throw ErrorHelp.genException(SysCode.System, ErrorCode.ACCOUNT_LOGIN_NOT, "");
            }

            body.setCreateTime(new Date());
            body.setUpdateTime(new Date());
            studentItemService.create(body);

            return ResponseMsgUtil.success("操作成功");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }



    @RequestMapping(value="/delete",method = RequestMethod.GET)
    @ResponseBody
    @ApiOperation(value = "删除")
    public ResponseData delete(@RequestParam(value = "id" , required = false) Long id) {
        try {

            studentItemService.delete(id , false);

            return ResponseMsgUtil.success("删除成功");

        } catch (Exception e) {
            log.error("error!",e);
            return ResponseMsgUtil.exception(e);
        }
    }
}